=========================================================
Pegasusio for reading / writing single-cell genomics data
=========================================================

|PyPI|

.. |PyPI| image:: https://img.shields.io/pypi/v/pegasuspy.svg
   :target: https://pypi.org/project/pegasuspy


Pegasusio is the IO package for Pegasus.

`Read documentation <http://pegasus.readthedocs.io>`__
